@@ -1,7 +1,8 @@
 #' @export
-precintcon.plot.spi <- function(..., 
-  period          = 3, 
-  distribution    = "Gamma",
+precintcon.plot.spi <- function(
+   ..., 
+	period          = 3, 
+   distribution   = "Gamma",
 	xlab            = "Months",
 	ylab            = "SPI", 
 	ylim            = c(-3,3),
@@ -11,9 +12,8 @@ precintcon.plot.spi <- function(...,
 	export          = FALSE, 
 	export.name     = "spi_plot.png", 
 	width           = 8.6, 
-  height          = 7.5, 
-  units           = "cm",
-  args            = NA
+   height         = 7.5, 
+   units          = "cm"
 ) {
 
 	l <- list(...)
@@ -25,7 +25,7 @@ precintcon.plot.spi <- function(...,
 		
 		l <- lapply(l, FUN = precintcon.spi.analysis, period = period, distribution = distribution)
 		
-		varl <- ifelse(is.na(args), as.character(match.call()[1:length(l)+1]), args)
+		varl <- as.list(match.call()[1:length(l)+1])
 		
 		if (!is.null(legend) && length(varl) != length(legend))
 			stop(paste("legend should has length equals to the number of input data. legend parameter length", 
@@ -52,14 +52,16 @@ precintcon.plot.spi <- function(...,
 					
 		par(ask = F)
 		
-	} else stop("empty input data in precintcon.plot.spi function.")
+	} else {
+		stop("empty input data in precintcon.plot.spi function.")
+	}
 }
 
 p.plot.spi <- function(d, n,
-		xlab            = "Periods",
-		ylab            = "SPI", 
-		ylim            = c(-3,3),
-		fontsize        = 10, 
+		xlab = "Periods",
+		ylab = "SPI", 
+		ylim = c(-3,3),
+		fontsize = 10, 
 		axis.text.color = "black"
 ) {
 	
@@ -72,18 +74,16 @@ p.plot.spi <- function(d, n,
 			y = d[ ,3], dataset = paste(n, sep=""))
 		
 		p <- ggplot(data) + geom_line(aes_string(x = "x", y = "y"), size = .3) + 
-				xlab(xlab) + 
-		    ylab(ylab) + 
-				scale_x_date(expand   = c(1/48, 1/48), 
-						limits            = as.Date(c(data[1,1], tail(data$x, n = 1))), 
-						date_breaks       = "20 months", labels = date_format("%b %y"), 
+				xlab(xlab) + ylab(ylab) + 
+				scale_x_date(expand = c(1/48, 1/48), 
+						limits = as.Date(c(data[1,1], tail(data$x, n = 1))), 
+						date_breaks = "20 months", labels = date_format("%b %y"), 
 						date_minor_breaks = "1 month") +
 				scale_y_continuous(breaks = seq(-3, 3, by = 1), limits = c(-3.5, 3.5)) +
-				theme(text           = element_text(size = fontsize), 
-					axis.text          = element_text(color = axis.text.color),
-					axis.text.x        = element_text(angle = 25),
-					axis.title.x       = element_text(vjust = .1),
-					panel.grid.minor.x = element_blank()) +
+				theme(text = element_text(size = fontsize), 
+					axis.text = element_text(color = axis.text.color),
+					axis.text.x = element_text(angle = 25),
+					axis.title.x = element_text(vjust = .1)) +
 			facet_grid(. ~ dataset)
 
 	return(p)
